//region Imports
'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
var bump = require('gulp-bump');
var git = require('gulp-git');
var tap = require('gulp-tap');
var filter = require('gulp-filter');
var cwd = require('cwd');
//endregion

exports['default'] = function (gulp, opts) {

  var makeBumpTask = function makeBumpTask(type) {
    var bumpTask = function bumpTask() {
      return gulp.src(['./package.json']).pipe(bump({ type: type })).pipe(gulp.dest('./'));
    };
    return gulp.series(bumpTask, 'bump:git:add', 'bump:git:commit', 'bump:git:commit-tag');
  };

  gulp.task('bump:git:add', function () {
    return gulp.src('./package.json').pipe(git.add());
  });

  gulp.task('bump:git:commit', function () {
    var json = require(cwd('package.json'));
    var version = json.version;

    return gulp.src('./package.json').pipe(git.commit(version));
  });

  gulp.task('bump:git:commit-tag', function (done) {
    var json = require(cwd('package.json'));
    var version = json.version;

    git.tag('v' + version, 'Bump', function (e) {
      if (e) return done(e);
      done();
    });
  });

  gulp.task('bump:patch', makeBumpTask('patch'));
  gulp.task('bump:minor', makeBumpTask('minor'));
  gulp.task('bump:major', makeBumpTask('major'));
  gulp.task('bump', makeBumpTask('patch'));
};

module.exports = exports['default'];