//region Imports
const git = require('gulp-git')
const deploy = require('gulp-gh-pages')
const fs = require('fs')
const cwd = require('cwd')
const confirm = require('inquirer-confirm')
const {spawn, execSync} = require('child_process')
const _ = require('lodash')
//endregion

export default function(gulp, opts) {

  gulp.task('publish:confirm', (done) => {
    const version = execSync('npm show . version', {encoding: 'utf8'})
    const pjson = require(cwd('package.json'))
    console.log('Last published version:', _.trim(version))
    console.log('Local package version:', pjson.version)
    confirm(`Are you sure you want to publish/tag v${pjson.version}`).then(() => { done() }, done)
  })

  gulp.task('publish:tag', function(done) {
    let pjson = require(cwd('package.json'))
    let v = 'v' + pjson.version
    let message = 'Release ' + v
    git.tag(v, message, function(e) {
      if (e) throw e
      git.push('origin', v, function(e) {
        if (e) throw e
        done()
      })
    })
  })

  gulp.task('publish:npm', function(done) {
    let pkg = require(cwd('package.json'))
    confirm(`Are you sure you want to publish v${pkg.version}`).then(() => {
      spawn('npm', ['publish'], {stdio: 'inherit'})
        .on('close', done)
    }, done)
  })

  gulp.task('release', gulp.series('publish:confirm', 'publish:npm', 'publish:tag'))

}
